@@ -369,6 +369,9 @@ extern struct litest_test_device litest_mouse_gladius_device;
 extern struct litest_test_device litest_mouse_wheel_click_angle_device;
 extern struct litest_test_device litest_apple_keyboard_device;
 extern struct litest_test_device litest_anker_mouse_kbd_device;
+extern struct litest_test_device litest_cyborg_rat_device;
+extern struct litest_test_device litest_yubikey_device;
+extern struct litest_test_device litest_synaptics_i2c_device;
 
 struct litest_test_device* devices[] = {
 	&litest_synaptics_clickpad_device,
@@ -404,6 +407,9 @@ struct litest_test_device* devices[] = {
 	&litest_mouse_wheel_click_angle_device,
 	&litest_apple_keyboard_device,
 	&litest_anker_mouse_kbd_device,
+	&litest_cyborg_rat_device,
+	&litest_yubikey_device,
+	&litest_synaptics_i2c_device,
 	NULL,
 };
 
@@ -1238,6 +1244,7 @@ litest_delete_device(struct litest_device *d)
 	libinput_path_remove_device(d->libinput_device);
 	if (d->owns_context)
 		libinput_unref(d->libinput);
+	close(libevdev_get_fd(d->evdev));
 	libevdev_free(d->evdev);
 	libevdev_uinput_destroy(d->uinput);
 	free(d->private);
